#[non_exhaustive]pub struct HttpRpcProviderConfig {
pub http_urls: Vec<UrlRedacted>,
pub chain_id: Option<ChainId>,
pub confirmations_poll_interval: Option<Duration>,
pub retry_policy_config: RetryPolicyConfig,
}Expand description
Configuration for building an HttpRpcProvider.
Multiple HTTP endpoints can be provided to enable automatic failover.
Retry behavior can be tuned via RetryPolicyConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.http_urls: Vec<UrlRedacted>List of HTTP RPC endpoints used for requests.
Uses alloy’s FallbackService and configures each endpoint as one potential transport.
chain_id: Option<ChainId>Optional chain ID used by the provider.
If provided, the ChainIdFiller will automatically populate
transactions with this value.
confirmations_poll_interval: Option<Duration>The poll interval for the confirmation heartbeat for alloy.
Uses alloy’s default setting if omitted. For dev environment 250ms
and for all other environments 7s.
retry_policy_config: RetryPolicyConfigRetry configuration applied to RPC requests.
Implementations
Sourceimpl HttpRpcProviderConfig
impl HttpRpcProviderConfig
Sourcepub fn with_default_values<I, U>(http_urls: I) -> Result<Self>where
I: IntoIterator<Item = U>,
U: IntoUrl,
pub fn with_default_values<I, U>(http_urls: I) -> Result<Self>where
I: IntoIterator<Item = U>,
U: IntoUrl,
Creates a new configuration using default retry settings.
Errors
Returns an error if any of the provided URLs cannot be parsed.